import type { CreateUser } from '../models/CreateUser';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseUser } from '../models/ResponseUser';
import type { UpdateUser } from '../models/UpdateUser';
export declare class UserService {
    /**
     * Get all
     * Lists all users. <br> This includes their groups and permissions granted to them.
     * @returns ResponseUser
     * @throws ApiError
     */
    static userControllerGetAll(): Promise<Array<ResponseUser>>;
    /**
     * Post
     * Create a new user. <br> If you want to grant permissions to the user you have to create them seperately by posting to /api/permissions after creating the user.
     * @param requestBody CreateUser
     * @returns ResponseUser
     * @throws ApiError
     */
    static userControllerPost(requestBody?: CreateUser): Promise<ResponseUser>;
    /**
     * Get one
     * Lists all information about the user whose id got provided. <br> Please remember that all permissions granted to the user will show up here.
     * @param id
     * @returns ResponseUser
     * @throws ApiError
     */
    static userControllerGetOne(id: number): Promise<ResponseUser>;
    /**
     * Put
     * Update the user whose id you provided. <br> To change the permissions directly granted to the user please use /api/permissions instead. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateUser
     * @returns ResponseUser
     * @throws ApiError
     */
    static userControllerPut(id: number, requestBody?: UpdateUser): Promise<ResponseUser>;
    /**
     * Remove
     * Delete the user whose id you provided. <br> You have to confirm your decision by providing the ?force=true query param. <br> If there are any permissions directly granted to the user they will get deleted as well. <br> If no user with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @returns ResponseUser
     * @returns ResponseEmpty
     * @throws ApiError
     */
    static userControllerRemove(id: number, force?: boolean): Promise<ResponseUser | ResponseEmpty>;
    /**
     * Get permissions
     * Lists all permissions granted to the user sorted into directly granted and inherited as permission response objects.
     * @param id
     * @returns ResponseUser
     * @throws ApiError
     */
    static userControllerGetPermissions(id: number): Promise<ResponseUser>;
}
